#ifndef POINT_H
#define POINT_H

class point
{
public:
	int x;
	int y;
};

#endif
